pub struct Config {
pub received_at: DateTime<Utc>,
pub sent_at: Option<DateTime<Utc>>,
pub max_in_past: Option<Duration>,
pub max_in_future: Option<Duration>,
pub minimum_clock_drift: Duration,
}Expand description
Configuration parameters for normalize.
Fields
received_at: DateTime<Utc>Timestamp when the item was received.
sent_at: Option<DateTime<Utc>>Client local timestamp when the SDK sent the item.
max_in_past: Option<Duration>Maximum amount of time the timestamp is allowed to be in the past.
max_in_future: Option<Duration>Maximum amount of time the timestamp is allowed to be in the future.
minimum_clock_drift: DurationLimits clock drift correction to a minimum duration.