TimeNormalize

Trait TimeNormalize 

pub trait TimeNormalize: ProcessValue {
    // Required methods
    fn reference_timestamp_mut(&mut self) -> &mut Annotated<Timestamp>;
    fn timestamp_sequence(&self) -> Option<u32>;
}
Items which can be processed by normalize.

Required Methods

fn reference_timestamp_mut(&mut self) -> &mut Annotated<Timestamp>

The base, reference timestamp of the item used for time shifts.

Represents the timestamp when the item was created.

fn timestamp_sequence(&self) -> Option<u32>

A tie breaker sent from SDKs for timestamps.

This is usually stored in SENTRY__TIMESTAMP__SEQUENCE and applied as additional nanoseconds to the timestamp.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementations on Foreign Types

Source

impl TimeNormalize for OurLog

Source

impl TimeNormalize for Replay

Source

impl TimeNormalize for SpanV2

Source

impl TimeNormalize for TraceMetric

Implementors