normalize

Function normalize 

pub fn normalize<T>(item: &mut Annotated<T>, config: Config)
where T: TimeNormalize,
Normalizes and validates timestamps.

Applies a time shift correction to correct for time drift on clients, see ClockDriftProcessor. Also makes sure timestamps are within boundaries defined by Config::max_in_past and Config::max_in_future.